import {
  Environment,
  commonApiUrls,
  commonApiacceptableFileExtensions,
  publicApiUrls,
  externalApiUrls,
  piUrls,
  protocolUrls,
  messageApiUrls,
  promptUrls
} from './environment.type';
import { DeviceType } from '@ucap-webmessenger/core';

export const environment: Environment = {
  production: true,
  title: `DS Talk`,

  companyConfig: {
    companyGroupCode: 'LG',
    fixedCompanyCode: 'GUC100'
  },

  productConfig: {
    productId: 'PRO_000482',
    productName: 'EZMessenger',
    authentication: {
      usePrivateInformationAgree: false,
      rememberMe: {
        use: false
      },
      autoLogin: {
        use: true
      }
    },
    updateCheckConfig: {
      deviceType: DeviceType.Renderer,
      intervalHour: 1
    },
    defaultSettings: {
      general: {
        appTheme: 'theme-default',
        autoLogin: false,
        autoLaunch: true,
        continueRunWhenClose: true,
        locale: 'ko',
        hrInfoLocale: 'ko',
        startupHideWindow: false,
        timezone: 'Asia/Seoul'
      },
      notification: {
        use: true,
        method: 'SOUND_ALERT',
        alertExposureTime: 5,
        receiveForMobile: false,
        receiveForMessage: false
      }
    },
    CommonSetting: {
      editableProfileImage: false,

      useTimerRoom: false,
      timerRoomDefaultInterval: 24 * 60 * 60,

      maxChatRoomUser: 300,
      masstextLength: 800,

      eventRequestDefaultCount: 50,

      readHereShowMinimumEventCount: 10,
      readHereShowMaximumEventCount: 100,
      readHereEventRequestCount: 10
    }
  },

  customConfig: {
    pw: {
      userKey: 'DaesangSSOProject',
      isBase64: 'N'
    },
    appKey: '!@#$DAESANG%^&*',

    /** 삭제,수정 불가 그룹 Seqs:number[] */
    fixedGroupSeqs: [-5]
  },

  commonApiModuleConfig: {
    hostConfig: {
      protocol: 'https',
      domain: 'messenger.daesang.com',
      port: 443
    },
    urls: commonApiUrls,
    acceptableFileExtensions: commonApiacceptableFileExtensions
  },

  publicApiModuleConfig: {
    hostConfig: {
      protocol: 'https',
      domain: 'messenger.daesang.com',
      port: 443
    },
    urls: publicApiUrls
  },

  externalApiModuleConfig: {
    hostConfig: {
      protocol: 'https',
      domain: 'messenger.daesang.com',
      port: 443
    },
    urls: externalApiUrls
  },

  messageApiModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: 'messenger.daesang.com',
      port: 9098
    },
    urls: messageApiUrls
  },

  promptApiModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: 'messenger.daesang.com',
      port: 9097
    },
    urls: promptUrls
  },

  piModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: 'messenger.daesang.com',
      port: 9097
    },
    urls: piUrls
  },

  protocolModuleConfig: {
    hostConfig: {
      protocol: 'ws',
      domain: 'messenger.daesang.com',
      port: 8080
    },
    urls: protocolUrls,
    reconnect: {
      delay: 1000
    },
    requestId: {
      min: 1,
      max: 59999
    }
  },

  nativeModuleConfig: {}
};
